@@ -1,6 +1,8 @@
+use strict;
+use warnings;
 package IPC::Run3::ProfArrayBuffer;
 
-$VERSION = 0.043;
+our $VERSION = 0.049;
 
 =head1 NAME
 
@@ -10,10 +12,6 @@ IPC::Run3::ProfArrayBuffer - Store profile events in RAM in an array
 
 =head1 DESCRIPTION
 
-=cut
-
-use strict;
-
 =head1 METHODS
 
 =over
